<?php
// If uninstall.php is not called by WordPress, stop
if (!defined('WP_UNINSTALL_PLUGIN')) {
    die;
}
function wpim_flush_rewrite_rules(): void {
    global $wp_rewrite;
}
function wpim_plugin_get_htaccess(WP_Filesystem_Base $filesystem ): ?string {
    $htaccess_file = get_home_path() . '.htaccess';
    if ( ! $filesystem->exists( $htaccess_file ) || ! $filesystem->is_readable( $htaccess_file ) || ! $filesystem->is_writable( $htaccess_file ) ) {
        return null;
    }
    return $htaccess_file;
}
function wpim_get_filesystem(): ?WP_Filesystem_Base {

    global $wp_filesystem;

    return $wp_filesystem;
}

function wpim_cleanup_htaccess(): void {
    $filesystem = wpim_get_filesystem();
    if ( null === $filesystem ) {
        return;
    }

    $htaccess_file = wpim_plugin_get_htaccess( $filesystem );
    if ( null === $htaccess_file ) {
        return;
    }

    $htaccess_contents = $filesystem->get_contents( $htaccess_file );
    if ( false === $htaccess_contents ) {
        return;
    }

    // This regex should match our whole block, both current and older versions.
    $regex             = '/\n*# (BEGIN )?(WordPress )?WPIM - XSS Protection?\d+\.\d+\.\d+[^#]+\n# END (WordPress )?WPIM - XSS Protection[^\n]*\n*/ism';
    $htaccess_contents = preg_replace( $regex, "\n\n", $htaccess_contents );
    $filesystem->put_contents( $htaccess_file, $htaccess_contents );

    wpim_flush_rewrite_rules();
}

//Delete plugin options
delete_option('wpim_mail_notifications');
delete_option('wpim_countryban_blacklist');
delete_option('wpim_sqli_protection');
delete_option('wpim_sqli_protection2');
delete_option('wpim_sqli_protection3');
delete_option('wpim_sqli_protection4');
delete_option('wpim_sqli_protection5');
delete_option('wpim_sqli_protection6');
delete_option('wpim_sqli_logging');
delete_option('wpim_sqli_autoban');
delete_option('wpim_sqli_mail');
delete_option('wpim_sqli_redirect');
delete_option('wpim_badbot_protection');
delete_option('wpim_badbot_protection2');
delete_option('wpim_badbot_protection3');
delete_option('wpim_badbot_logging');
delete_option('wpim_badbot_autoban');
delete_option('wpim_badbot_mail');
delete_option('wpim_proxy_protection');
delete_option('wpim_proxy_protection2');
delete_option('wpim_proxy_api1');
delete_option('wpim_proxy_api2');
delete_option('wpim_proxy_api3');
delete_option('wpim_proxy_logging');
delete_option('wpim_proxy_mail');
delete_option('wpim_proxy_redirect');
delete_option('wpim_spam_protection');
delete_option('wpim_spam_logging');
delete_option('wpim_spam_mail');
delete_option('wpim_spam_redirect');
delete_option('wpim_live_traffic');
delete_option('wpim_error_reporting');
delete_option('wpim_display_errors');
delete_option('wpim_banned_redirect');
delete_option('wpim_bannedc_redirect');
delete_option('wpim_bannedo_redirect');
delete_option('wpim_bannedb_redirect');
delete_option('wpim_bannedi_redirect');
delete_option('wpim_bannedr_redirect');
wpim_cleanup_htaccess();
delete_option('wpim_max_age');
delete_option('wpim_include_subdomains');
delete_option('wpim_preload');
delete_option('wpim_csp');

// For site options in Multisite
delete_site_option('wpim_mail_notifications');
delete_site_option('wpim_countryban_blacklist');
delete_site_option('wpim_sqli_protection');
delete_site_option('wpim_sqli_protection2');
delete_site_option('wpim_sqli_protection3');
delete_site_option('wpim_sqli_protection4');
delete_site_option('wpim_sqli_protection5');
delete_site_option('wpim_sqli_protection6');
delete_site_option('wpim_sqli_logging');
delete_site_option('wpim_sqli_autoban');
delete_site_option('wpim_sqli_mail');
delete_site_option('wpim_sqli_redirect');
delete_site_option('wpim_badbot_protection');
delete_site_option('wpim_badbot_protection2');
delete_site_option('wpim_badbot_protection3');
delete_site_option('wpim_badbot_logging');
delete_site_option('wpim_badbot_autoban');
delete_site_option('wpim_badbot_mail');
delete_site_option('wpim_proxy_protection');
delete_site_option('wpim_proxy_protection2');
delete_site_option('wpim_proxy_api1');
delete_site_option('wpim_proxy_api2');
delete_site_option('wpim_proxy_api3');
delete_site_option('wpim_proxy_logging');
delete_site_option('wpim_proxy_autoban');
delete_site_option('wpim_proxy_mail');
delete_site_option('wpim_proxy_redirect');
delete_site_option('wpim_spam_protection');
delete_site_option('wpim_spam_logging');
delete_site_option('wpim_spam_autoban');
delete_site_option('wpim_spam_mail');
delete_site_option('wpim_spam_redirect');
delete_site_option('wpim_live_traffic');
delete_site_option('wpim_error_reporting');
delete_site_option('wpim_display_errors');
delete_site_option('wpim_banned_redirect');
delete_site_option('wpim_bannedc_redirect');
delete_site_option('wpim_bannedo_redirect');
delete_site_option('wpim_bannedb_redirect');
delete_site_option('wpim_bannedi_redirect');
delete_site_option('wpim_bannedr_redirect');

// Delete Warning Pages
if (get_page_by_title('Banned') != NULL) {
    $page = get_page_by_title('Banned');
    wp_delete_post($page->ID, true);
}
if (get_page_by_title('Blocked Request') != NULL) {
    $page = get_page_by_title('Blocked Request');
    wp_delete_post($page->ID, true);
}
if (get_page_by_title('Proxy Detected') != NULL) {
    $page = get_page_by_title('Proxy Detected');
    wp_delete_post($page->ID, true);
}
if (get_page_by_title('Spam IP') != NULL) {
    $page = get_page_by_title('Spam IP');
    wp_delete_post($page->ID, true);
}
if (get_page_by_title('Banned Country') != NULL) {
    $page = get_page_by_title('Banned Country');
    wp_delete_post($page->ID, true);
}
if (get_page_by_title('Banned Browser') != NULL) {
    $page = get_page_by_title('Banned Browser');
    wp_delete_post($page->ID, true);
}
if (get_page_by_title('Banned OS') != NULL) {
    $page = get_page_by_title('Banned OS');
    wp_delete_post($page->ID, true);
}
if (get_page_by_title('Banned ISP') != NULL) {
    $page = get_page_by_title('Banned ISP');
    wp_delete_post($page->ID, true);
}
if (get_page_by_title('Banned Referer') != NULL) {
    $page = get_page_by_title('Banned Referer');
    wp_delete_post($page->ID, true);
}

// Drop custom database tables
global $wpdb;
$wpdb->query("DROP TABLE IF EXISTS {$wpdb->prefix}wpim_logs");
$wpdb->query("DROP TABLE IF EXISTS {$wpdb->prefix}wpim_bans");
$wpdb->query("DROP TABLE IF EXISTS {$wpdb->prefix}wpim_ipwhitelist");
$wpdb->query("DROP TABLE IF EXISTS {$wpdb->prefix}wpim_dnsbl");
$wpdb->query("DROP TABLE IF EXISTS {$wpdb->prefix}wpim_livetraffic");
$wpdb->query("DROP TABLE IF EXISTS {$wpdb->prefix}wpim_loginhistory");
$wpdb->query("DROP TABLE IF EXISTS {$wpdb->prefix}wpim_filewhitelist");
?>